@@ -1,6 +1,6 @@
 import numpy as np
 import matplotlib.pyplot as plt
-from matplotlib.patches import Rectangle,Circle
+from matplotlib.patches import Rectangle,Circle,Wedge
 from matplotlib.figure import Figure
 from matplotlib.axes import Axes
 
@@ -135,7 +135,6 @@ def show_rect(ar,min=0,max=3,power=1,figsize=(12,12),returnfig=False,
 
     fig,ax = show(ar,min,max,power,figsize,returnfig=True,**kwargs)
 
-    rects = []
     for i in range(N):
         l,c,f,a,lw = lims[i],color[i],fill[i],alpha[i],linewidth[i]
         rect = Rectangle((l[2]-0.5,l[0]-0.5),l[3]-l[2],l[1]-l[0],color=c,fill=f,
@@ -152,7 +151,7 @@ def show_circ(ar,min=0,max=3,power=1,figsize=(12,12),returnfig=False,
               center=(0,0),R=10,color='r',fill=True,alpha=1,linewidth=2,**kwargs):
     """
     Visualization function which plots a 2D array with one or more overlayed circles.
-    To overlay one circle, center must be a single 2-tuple.  To overlay N rectangles,
+    To overlay one circle, center must be a single 2-tuple.  To overlay N circles,
     center must be a list of N 2-tuples.  color, fill, and alpha may each be single values,
     which are then applied to all the circles, or a length N list.
 
@@ -215,7 +214,6 @@ def show_circ(ar,min=0,max=3,power=1,figsize=(12,12),returnfig=False,
 
     fig,ax = show(ar,min,max,power,figsize,returnfig=True,**kwargs)
 
-    rects = []
     for i in range(N):
         cent,r,col,f,a,lw = center[i],R[i],color[i],fill[i],alpha[i],linewidth[i]
         circ = Circle((cent[1],cent[0]),r,color=col,fill=f,alpha=a,linewidth=lw)
@@ -227,6 +225,89 @@ def show_circ(ar,min=0,max=3,power=1,figsize=(12,12),returnfig=False,
     else:
         return fig,ax
 
+def show_annuli(ar,min=0,max=3,power=1,figsize=(12,12),returnfig=False,
+              center=(0,0),Ri=10,Ro=20,color='r',fill=True,alpha=1,linewidth=2,**kwargs):
+    """
+    Visualization function which plots a 2D array with one or more overlayed annuli.
+    To overlay one annulus, center must be a single 2-tuple.  To overlay N annuli,
+    center must be a list of N 2-tuples.  color, fill, and alpha may each be single values,
+    which are then applied to all the circles, or a length N list.
+
+    See the docstring for py4DSTEM.visualize.show() for descriptions of all input
+    parameters not listed below.
+
+    Accepts:
+        center      (2-tuple, or list of N 2-tuples) the center of the annulus (x0,y0)
+        Ri,Ro       (number of list of N numbers) the inner and outer radii
+        color       (string of list of N strings)
+        fill        (bool or list of N bools) filled in or empty rectangles
+        alpha       (number, 0 to 1) transparency
+        linewidth   (number)
+
+    Returns:
+        If returnfig==False (default), the figure is plotted and nothing is returned.
+        If returnfig==False, the figure and its one axis are returned, and can be
+        further edited.
+    """
+    if isinstance(center,tuple):
+        assert(len(center)==2)
+        center = [center]
+        N = 1
+    else:
+        assert(isinstance(center,list))
+        assert(all([isinstance(c,tuple) for c in center]))
+        assert(all([len(c)==2 for c in center]))
+        N = len(center)
+    if isinstance(Ri,(float,int,np.float)):
+        Ri = [Ri for i in range(N)]
+    if isinstance(Ro,(float,int,np.float)):
+        Ro = [Ro for i in range(N)]
+    else:
+        assert(isinstance(Ri,list))
+        assert(len(Ri)==N)
+        assert(all([isinstance(r,(float,int,np.float)) for r in Ri]))
+        assert(isinstance(Ro,list))
+        assert(len(Ro)==N)
+        assert(all([isinstance(r,(float,int,np.float)) for r in Ro]))
+    if isinstance(color,str):
+        color = [color for i in range(N)]
+    else:
+        assert(isinstance(color,list))
+        assert(len(color)==N)
+        assert(all([isinstance(c,str) for c in color]))
+    if isinstance(fill,bool):
+        fill = [fill for i in range(N)]
+    else:
+        assert(isinstance(fill,list))
+        assert(len(fill)==N)
+        assert(all([isinstance(f,bool) for f in fill]))
+    if isinstance(alpha,(float,int,np.float)):
+        alpha = [alpha for i in range(N)]
+    else:
+        assert(isinstance(alpha,list))
+        assert(len(alpha)==N)
+        assert(all([isinstance(a,(float,int,np.float)) for a in alpha]))
+    if isinstance(linewidth,(float,int,np.float)):
+        linewidth = [linewidth for i in range(N)]
+    else:
+        assert(isinstance(linewidth,list))
+        assert(len(linewidth)==N)
+        assert(all([isinstance(lw,(float,int,np.float)) for lw in linewidth]))
+
+
+    fig,ax = show(ar,min,max,power,figsize,returnfig=True,**kwargs)
+
+    for i in range(N):
+        cent,ri,ro,col,f,a,lw = center[i],Ri[i],Ro[i],color[i],fill[i],alpha[i],linewidth[i]
+        annulus = Wedge((cent[1],cent[0]),ro,0,360,width=ro-ri,color=col,fill=f,alpha=a,linewidth=lw)
+        ax.add_patch(annulus)
+
+    if not returnfig:
+        plt.show()
+        return
+    else:
+        return fig,ax
+
 def show_points(ar,x,y,s=1,scale=500,alpha=1,point_color='r',
                 min=0,max=3,power=1,figsize=(12,12),returnfig=False,**kwargs):
     """
